@@ -24,6 +24,7 @@
 
 #include <config.h>
 #include <gtk/gtk.h>
+#include <gio/gdesktopappinfo.h>
 #include <string.h>
 #ifdef VINO_ENABLE_LIBNOTIFY
 #include <libnotify/notify.h>
@@ -199,16 +200,23 @@ static void
 vino_status_icon_preferences (VinoStatusIcon *icon)
 {
   GdkScreen *screen;
+  GDesktopAppInfo *info;
+  GdkAppLaunchContext *context;
   GError *error = NULL;
 
   screen = gtk_status_icon_get_screen (GTK_STATUS_ICON (icon));
-  if (!gdk_spawn_command_line_on_screen (screen, "vino-preferences", &error))
+  info = g_desktop_app_info_new ("vino-preferences.desktop");
+  context = gdk_display_get_app_launch_context (gdk_screen_get_display (screen));
+  if (!g_app_info_launch (G_APP_INFO (info), NULL, G_APP_LAUNCH_CONTEXT (context), &error))
     {
       vino_util_show_error (_("Error displaying preferences"),
-			    error->message,
-			    NULL);
+                            error->message,
+                            NULL);
       g_error_free (error);
     }
+
+  g_object_unref (info);
+  g_object_unref (context);
 }
 
 static void
@@ -272,7 +280,8 @@ vino_status_icon_about (VinoStatusIcon *icon)
 
   gtk_show_about_dialog (NULL,
                          "comments",           _("Share your desktop with other users"),
-                         "version",            VERSION,
+                         "version",            PACKAGE_VERSION,
+                         "website",            PACKAGE_URL,
                          "license",            license,
                          "authors",            authors,
                          "translator-credits", translators,
